==> dde-session-shell_5.5.34.tar.xz: BUILD/translations/dde-session-shell_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Kasvojen tunnistus</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Vahvista kasvojen tunnistuksella</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Kasvojen tunnistus lukittu, käytä salasanaa</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Vahvista sormenjälläsi</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Sormenjälki lukittu, käytä salasanaa</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iriksen tunnus</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Vahvista iriksen tunnistuksella</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iriksen tunnistus lukittu, käytä salasanaa</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Väärä salasana</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Nollaa salasana</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Unohtuiko salasana?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Nollaa salasana</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Unohtuiko salasana?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform><numerusform>Tarkistus epäonnistui, %n yritystä jäljellä</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Väärä PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey vaaditaan</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Anna PIN-koodisi</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform><numerusform>Yritä uudelleen %n minuuttia myöhemmin</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Käyttäjätili</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Salasanasi vanhenee %n päivän kuluttua, vaihda se ajoissa</numerusform><numerusform>Salasanasi vanhenee %n päivän kuluttua, vaihda se ajoissa</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Salasana vanhentunut, vaihda</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Väärä tili</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Väärä salasana</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Lukitse näyttö</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Näytön lukitseminen epäonnistui</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Sormenjäljen tarkistus aikakatkaistiin, ole hyvä ja anna salasana manuaalisesti</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Sormenjälkeä ei tunnistettu</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Edellä mainitut käyttäjät ovat vielä kirjautuneet sisään ja tiedot katoavat, koska haluat sammuttaa?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Edellä mainitut käyttäjät ovat vielä kirjautuneet sisään ja tiedot katoavat uudelleenkäynnistyksen takia, haluatko varmasti uudelleenkäynnistyksen?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Olet ottanut käyttöön korkean järjestelmän suojaustason, joten et voi vaihtaa Wayland-tilaan. Poista suojaustaso Turvakeskuksesta ja yritä uudelleen.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukitse</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Vaihda käyttäjää</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Vaihda järjestelmää</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Käynnistä järjestelmänhallinta</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Ohjelmat estävät tietokoneen sammutusta ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Valitse ensin Peruuta ja sulje sitten avoin ohjelma.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät käynnistyksen uudelleen ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät valmiustilan ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät lepotilan ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät kirjautumisen ulos ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Haluatko varmasti sulkea?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Haluatko käynnistää uudelleen?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Haluatko kirjautua ulos?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
</context>
</TS>

==> dde-session-shell_6.0.21.tar.xz: BUILD/translations/dde-session-shell_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Kasvojen tunnistus</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Vahvista kasvojen tunnistuksella</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Kasvojen tunnistus lukittu, käytä salasanaa</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Laite ei ole käytettävissä!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Vahvista sormenjälläsi</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Sormenjälki lukittu, käytä salasanaa</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iriksen tunnus</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Vahvista iriksen tunnistuksella</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iriksen tunnistus lukittu, käytä salasanaa</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Väärä salasana</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Salasana</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Nollaa salasana</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Unohtuiko salasana?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Nollaa salasana</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Unohtuiko salasana?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Tarkistus onnistui</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Tarkistus epäonnistui, yksi yritys jäljellä</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Väärä PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey vaaditaan</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Anna PIN-koodisi</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Yritä 1 minuutin jälkeen uudelleen</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Käyttäjätili</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Your password has expired. Please change it.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>ChangePasswordWidget</name>
    <message>
        <source>Your password has expired. Please change it and log in again.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Save</source>
        <translation>Tallenna</translation>
    </message>
    <message>
        <source>Old password</source>
        <translation>Vanha salasana</translation>
    </message>
    <message>
        <source>New password</source>
        <translation>Uusi salasana</translation>
    </message>
    <message>
        <source>Repeat new password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password hint (Optional)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passwords do not match</source>
        <translation>Salasanat eivät täsmää</translation>
    </message>
    <message>
        <source>The hint is visible to all users. Do not include the password here.</source>
        <translation>Vihje näkyy kaikille käyttäjille. Älä lisää salasanaa tähän.</translation>
    </message>
    <message>
        <source>New password should differ from the current one</source>
        <translation>Uusi salasana ei saa olla sama kuin nykyinen</translation>
    </message>
    <message>
        <source>Password changed</source>
        <translation>Salasana vaihdettu</translation>
    </message>
    <message>
        <source>Wrong password</source>
        <translation>Väärä salasana</translation>
    </message>
</context>
<context>
    <name>ControlWidget</name>
    <message>
        <source>Desktop Environment and Display Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Keyboard Layout</source>
        <translation>Näppäimistön asettelu</translation>
    </message>
    <message>
        <source>Switch User</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Power</source>
        <translation>Virta</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Väärä tili</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Väärä salasana</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Lukitse näyttö</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Näytön lukitseminen epäonnistui</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Sormenjäljen tarkistus aikakatkaistiin, ole hyvä ja anna salasana manuaalisesti</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Sormenjälkeä ei tunnistettu</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Edellä mainitut käyttäjät ovat vielä kirjautuneet sisään ja tiedot katoavat, koska haluat sammuttaa?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Edellä mainitut käyttäjät ovat vielä kirjautuneet sisään ja tiedot katoavat uudelleenkäynnistyksen takia, haluatko varmasti uudelleenkäynnistyksen?</translation>
    </message>
</context>
<context>
    <name>PasswordLevelWidget</name>
    <message>
        <source>Weak</source>
        <translation>Heikko</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Keskitaso</translation>
    </message>
    <message>
        <source>Strong</source>
        <translation>Vahva</translation>
    </message>
</context>
<context>
    <name>PwqualityManager</name>
    <message>
        <source>Password cannot be empty</source>
        <translation>Salasana ei voi olla tyhjä</translation>
    </message>
    <message>
        <source>Password must have at least %1 characters</source>
        <translation>Salasanassa on oltava vähintään %1 merkkiä</translation>
    </message>
    <message>
        <source>Password must be no more than %1 characters</source>
        <translation>Salasanassa saa olla enintään %1 merkkiä</translation>
    </message>
    <message>
        <source>Password can only contain English letters (case-sensitive), numbers or special symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Salasana voi sisältää vain englanninkielisiä kirjaimia (isot ja pienet kirjaimet), numeroita tai erikoismerkkejä (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <source>No more than %1 palindrome characters please</source>
        <translation>Enintään %1 merkkiä palindromina</translation>
    </message>
    <message>
        <source>No more than %1 monotonic characters please</source>
        <translation>Enintään %1 monotonista merkkiä peräkkäin</translation>
    </message>
    <message>
        <source>No more than %1 repeating characters please</source>
        <translation>Enintään %1 samaa merkkiä peräkkäin</translation>
    </message>
    <message>
        <source>Password must contain uppercase letters, lowercase letters, numbers and symbols (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</source>
        <translation>Salasanassa on oltava isoja kirjaimia, pieniä kirjaimia, numeroita ja symboleja (~`!@#$%^&amp;*()-_+=|\{}[]:&quot;&apos;&lt;&gt;,.?/)</translation>
    </message>
    <message>
        <source>Password must not contain more than 4 palindrome characters</source>
        <translation>Salasana ei saa sisältää takaperin enempää kuin 4 -merkkiä</translation>
    </message>
    <message>
        <source>Do not use common words and combinations as password</source>
        <translation>Älä käytä yleisiä sanoja ja yhdistelmiä salasanassa</translation>
    </message>
    <message>
        <source>Create a strong password please</source>
        <translation>Luo vahva salasana</translation>
    </message>
    <message>
        <source>It does not meet password rules</source>
        <translation>Tämä ei täytä salasanan sääntöjä</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Lukitse</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Vaihda järjestelmää</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Vaihda käyttäjää</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Käynnistä järjestelmänhallinta</translation>
    </message>
</context>
<context>
    <name>UserListPopupWidget</name>
    <message>
        <source>Standard User</source>
        <translation>Tavallinen käyttäjä</translation>
    </message>
    <message>
        <source>Administrator</source>
        <translation>Järjestelmänvalvoja</translation>
    </message>
    <message>
        <source>Other Users</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>VirtualKeyboardModule</name>
    <message>
        <source>Onboard</source>
        <translation>Näppäimistö</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Ohjelmat estävät tietokoneen sammutusta ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Valitse ensin Peruuta ja sulje sitten avoin ohjelma.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät käynnistyksen uudelleen ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät valmiustilan ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät lepotilan ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Avoimet ohjelmat estävät kirjautumisen ulos ja pakottaminen voi aiheuttaa tietojen menetyksen.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Sammuta</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Valmiustila</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Lepotila</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Kirjaudu ulos</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Haluatko varmasti sulkea?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Haluatko käynnistää uudelleen?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Haluatko kirjautua ulos?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Kytke käyttöön</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Poista käytöstä</translation>
    </message>
</context>
</TS>
